@@ -4,6 +4,8 @@
 ##'
 ##'
 ##' @param x A stratified (svy)TableOne object containing standardized mean differences.
+##' @param varLabels Whether to replace variable names with variable labels obtained from \code{labelled::var_label()} function.
+##'
 ##' @return A vector or matrix containing the average standardized mean differences (if more than two contrasts exist) as well as the all possible pairwise standardized mean differences. Variables are ordered in the same order as the printed table.
 ##' @author Kazuki Yoshida
 ##' @seealso
@@ -13,7 +15,7 @@
 ##' ## See examples for CreateTableOne and svyCreateTableOne
 ##'
 ##' @export
-ExtractSmd <- function(x) {
+ExtractSmd <- function(x, varLabels = FALSE) {
 
     if (class(x)[1] %in% c("TableOne","svyTableOne")) {
 
@@ -22,7 +24,20 @@ ExtractSmd <- function(x) {
                         attr(x$CatTable,  "smd"))
 
         ## Order by table variable order
-        matSmd[x$MetaData$vars,]
+        matSmd <- matSmd[x$MetaData$vars, , drop = FALSE]
+
+        ## Use variable labels if requested.
+        if (varLabels) {
+            for (i in seq_along(x$MetaData$vars)) {
+                if (!is.null(x$MetaData$varLabels[[i]])) {
+                    ## If the corresponding variable label is non-null replace
+                    rownames(matSmd)[i] <- x$MetaData$varLabels[[i]]
+                }
+            }
+        }
+
+        ## Return manipulated matrix
+        matSmd
 
     } else if (class(x)[1] %in% c("ContTable","svyContTable","CatTable","svyCatTable")) {
 
