@@ -18,9 +18,10 @@
 ##' @param exact A character vector to specify the variables for which the p-values should be those of exact tests. By default all p-values are from large sample approximation tests (chisq.test).
 ##' @param smd Whether to show standardized mean differences. FALSE by default. If there are more than one contrasts, the average of all possible standardized mean differences is shown. For individual contrasts, use \code{summary}.
 ##' @param CrossTable Whether to show the cross table objects held internally using gmodels::CrossTable function. This will give an output similar to the PROC FREQ in SAS.
+##' @param formatOptions A list of options, which will be passed to \code{\link[base]{format}}. Can be used to modify the \code{big.mark}, \code{decimal.mark}, \code{big.interval} etc. The default is \code{list(scientific = FALSE)}. The options digits, nsmall, justify and trim are not available. (Experimental)
 ##' @param ... For compatibility with generic. Ignored.
 ##' @return A matrix object containing what you see is also invisibly returned. This can be assinged a name and exported via \code{write.csv}.
-##' @author Kazuki Yoshida
+##' @author Kazuki Yoshida, Alexander Bartel
 ##' @seealso
 ##' \code{\link{CreateTableOne}}, \code{\link{CreateCatTable}}, \code{\link{summary.CatTable}}
 ##' @examples
@@ -104,7 +105,8 @@ function(x,                        # CatTable object
          smd           = FALSE,    # Whether to add standardized mean differences
 
          CrossTable    = FALSE,    # Whether to show gmodels::CrossTable
-
+         
+         formatOptions = list(scientific = FALSE),     # Options for formatting
          ...) {
 
     ## x and ... required to be consistent with generic print(x, ...)
@@ -136,6 +138,12 @@ function(x,                        # CatTable object
         warning("format only accepts one of fp, f, p, or pf. Choosing fp.")
         format <- "fp"
     }
+    
+    ## Set FormatOptions, delete reserved options
+    formatOptions$digits  <- digits
+    formatOptions$nsmall  <- digits
+    formatOptions$justify <- NULL
+    formatOptions$trim    <- NULL
 
     ## Obtain the strata sizes in a character vector. This has to be obtained from the original data
     ## Added as the top row later
@@ -147,7 +155,16 @@ function(x,                        # CatTable object
                           ## Pick the first non-null element
                           n[!is.null(n)][1]
                           ## Convert NULL to 0
-                          ifelse(is.null(n), "0", as.character(n))
+                          n <- ifelse(is.null(n), "0", n)
+                          ## Format n
+                          formatOptions$nsmall  <- 0
+                          n <- do.call(base::format, c(list(x = n,
+                                                            trim = TRUE),
+                                                       formatOptions
+                                                       )
+                                       )
+                          ## return as string
+                          as.character(n)
                       },
                       simplify = TRUE) # vector with as many elements as strata
 
@@ -166,7 +183,8 @@ function(x,                        # CatTable object
                           varsToFormat  = varsToFormat,
                           cramVars      = cramVars,
                           dropEqual     = dropEqual,
-                          showAllLevels = showAllLevels)
+                          showAllLevels = showAllLevels,
+                          formatOptions = formatOptions)
 
 
 ### Obtain the original column width in characters for alignment in print.TableOne
@@ -228,9 +246,10 @@ function(x,                        # CatTable object
         testTypes <- c("","exact")[exact]
 
         ## Pick the p-values requested, and format like <0.001
-        pVec <- ModulePickAndFormatPValues(TableObject = CatTable,
-                                           switchVec   = exact,
-                                           pDigits     = pDigits)
+        pVec <- ModulePickAndFormatPValues(TableObject   = CatTable,
+                                           switchVec     = exact,
+                                           pDigits       = pDigits,
+                                           formatOptions = formatOptions)
 
         ## Create an empty p-value column and test column
         out <- cbind(out,
@@ -256,7 +275,8 @@ function(x,                        # CatTable object
         ## Put the values at the non-empty positions
         out[logiNonEmptyRowNames,"SMD"] <-
         ModuleFormatPValues(attr(CatTable, "smd")[,1],
-                            pDigits = pDigits)
+                            pDigits         = pDigits,
+                            formatOptions   = formatOptions)
     }
 
 
@@ -267,7 +287,8 @@ function(x,                        # CatTable object
         out <- cbind(out,
                      Missing = rep("", nrow(out))) # Column for p-values
         ## Put the values at the non-empty positions
-        out[logiNonEmptyRowNames,"Missing"] <- ModuleFormatPercents(attr(CatTable, "percentMissing"), 1)
+        out[logiNonEmptyRowNames,"Missing"] <- ModuleFormatPercents(attr(CatTable, "percentMissing"), 
+                                                                    digits =  1, formatOptions = formatOptions)
     }
 
 
